@@ -56,7 +56,7 @@ module Gollum
 
       def self.create(repo, options)
         blob = repo.git.lookup(options[:id])
-        self.new(blob, options)
+        self.new(blob, **options)
       end
 
       def initialize(blob, options = {})
@@ -210,7 +210,7 @@ module Gollum
           @repo.checkout_head(**options)
         else
           ref = "refs/heads/#{ref}" unless ref =~ /^refs\/heads\//
-          @repo.checkout_tree(sha_from_ref(ref), options)
+          @repo.checkout_tree(sha_from_ref(ref), **options)
         end
       end
 
@@ -222,13 +222,13 @@ module Gollum
           :follow => false,
           :skip_merges => false
         }
-        options = default_options.merge(options)
+        options = default_options.merge(**options)
         options[:limit] ||= 0
         options[:offset] ||= 0
         sha = sha_from_ref(ref)
         return [] if sha.nil?
         begin
-          build_log(sha, options)
+          build_log(sha, **options)
         rescue Rugged::OdbError, Rugged::InvalidError, Rugged::ReferenceError
         # Return an empty array if the ref wasn't found
           []
@@ -236,7 +236,7 @@ module Gollum
       end
 
       def versions_for_path(path = nil, ref = nil, options = {})
-        log(ref, path, options)
+        log(ref, path, **options)
       end
 
       def ls_files(query, options = {})
@@ -285,13 +285,13 @@ module Gollum
 
       def push(remote, branches = nil, options = {})
         branches = [branches].flatten.map {|branch| "refs/heads/#{branch}" unless branch =~ /^refs\/heads\//}
-        @repo.push(remote, branches, options)
+        @repo.push(remote, branches, **options)
       end
 
       def pull(remote, branches = nil, options = {})
         branches = [branches].flatten.map {|branch| "refs/heads/#{branch}" unless branch =~ /^refs\/heads\//}
         r = @repo.remotes[remote]
-        r.fetch(branches, options)
+        r.fetch(branches, **options)
         branches.each do |branch|
           branch_name = branch.match(/^refs\/heads\/(.*)/)[1]
           remote_name = remote.match(/^(refs\/heads\/)?(.*)/)[2]
@@ -305,7 +305,7 @@ module Gollum
             tree: index.write_tree(@repo),
             update_ref: branch
           }
-          Rugged::Commit.create @repo, options
+          Rugged::Commit.create @repo, **options
           @repo.checkout(@repo.head.name, :strategy => :force) if !@repo.bare? && branch == @repo.head.name
         end
       end
@@ -603,7 +603,7 @@ module Gollum
       end
 
       def log(commit = 'refs/heads/master', path = nil, options = {})
-        git.log(commit, path, options)
+        git.log(commit, path, **options)
       end
 
       def lstree(sha, options = {})
